# frozen_string_literal: true

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Auto-generated by gapic-generator-ruby. DO NOT EDIT!

require "google/cloud/errors"
require "google/cloud/oslogin/v1beta/oslogin_pb"

module Google
  module Cloud
    module OsLogin
      module V1beta
        module OsLoginService
          ##
          # Client for the OsLoginService service.
          #
          # Cloud OS Login API
          #
          # The Cloud OS Login API allows you to manage users and their associated SSH
          # public keys for logging into virtual machines on Google Cloud Platform.
          #
          class Client
            include Paths

            # @private
            attr_reader :os_login_service_stub

            ##
            # Configure the OsLoginService Client class.
            #
            # See {::Google::Cloud::OsLogin::V1beta::OsLoginService::Client::Configuration}
            # for a description of the configuration fields.
            #
            # ## Example
            #
            # To modify the configuration for all OsLoginService clients:
            #
            #     ::Google::Cloud::OsLogin::V1beta::OsLoginService::Client.configure do |config|
            #       config.timeout = 10.0
            #     end
            #
            # @yield [config] Configure the Client client.
            # @yieldparam config [Client::Configuration]
            #
            # @return [Client::Configuration]
            #
            def self.configure
              @configure ||= begin
                namespace = ["Google", "Cloud", "OsLogin", "V1beta"]
                parent_config = while namespace.any?
                                  parent_name = namespace.join "::"
                                  parent_const = const_get parent_name
                                  break parent_const.configure if parent_const.respond_to? :configure
                                  namespace.pop
                                end
                default_config = Client::Configuration.new parent_config

                default_config.rpcs.delete_posix_account.timeout = 10.0
                default_config.rpcs.delete_posix_account.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14, 4]
                }

                default_config.rpcs.delete_ssh_public_key.timeout = 10.0
                default_config.rpcs.delete_ssh_public_key.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14, 4]
                }

                default_config.rpcs.get_login_profile.timeout = 10.0
                default_config.rpcs.get_login_profile.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14, 4]
                }

                default_config.rpcs.get_ssh_public_key.timeout = 10.0
                default_config.rpcs.get_ssh_public_key.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14, 4]
                }

                default_config.rpcs.import_ssh_public_key.timeout = 10.0
                default_config.rpcs.import_ssh_public_key.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14, 4]
                }

                default_config.rpcs.update_ssh_public_key.timeout = 10.0
                default_config.rpcs.update_ssh_public_key.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14, 4]
                }

                default_config
              end
              yield @configure if block_given?
              @configure
            end

            ##
            # Configure the OsLoginService Client instance.
            #
            # The configuration is set to the derived mode, meaning that values can be changed,
            # but structural changes (adding new fields, etc.) are not allowed. Structural changes
            # should be made on {Client.configure}.
            #
            # See {::Google::Cloud::OsLogin::V1beta::OsLoginService::Client::Configuration}
            # for a description of the configuration fields.
            #
            # @yield [config] Configure the Client client.
            # @yieldparam config [Client::Configuration]
            #
            # @return [Client::Configuration]
            #
            def configure
              yield @config if block_given?
              @config
            end

            ##
            # Create a new OsLoginService client object.
            #
            # ## Examples
            #
            # To create a new OsLoginService client with the default
            # configuration:
            #
            #     client = ::Google::Cloud::OsLogin::V1beta::OsLoginService::Client.new
            #
            # To create a new OsLoginService client with a custom
            # configuration:
            #
            #     client = ::Google::Cloud::OsLogin::V1beta::OsLoginService::Client.new do |config|
            #       config.timeout = 10.0
            #     end
            #
            # @yield [config] Configure the OsLoginService client.
            # @yieldparam config [Client::Configuration]
            #
            def initialize
              # These require statements are intentionally placed here to initialize
              # the gRPC module only when it's required.
              # See https://github.com/googleapis/toolkit/issues/446
              require "gapic/grpc"
              require "google/cloud/oslogin/v1beta/oslogin_services_pb"

              # Create the configuration object
              @config = Configuration.new Client.configure

              # Yield the configuration if needed
              yield @config if block_given?

              # Create credentials
              credentials = @config.credentials
              # Use self-signed JWT if the scope and endpoint are unchanged from default,
              # but only if the default endpoint does not have a region prefix.
              enable_self_signed_jwt = @config.scope == Client.configure.scope &&
                                       @config.endpoint == Client.configure.endpoint &&
                                       !@config.endpoint.split(".").first.include?("-")
              credentials ||= Credentials.default scope: @config.scope,
                                                  enable_self_signed_jwt: enable_self_signed_jwt
              if credentials.is_a?(String) || credentials.is_a?(Hash)
                credentials = Credentials.new credentials, scope: @config.scope
              end
              @quota_project_id = @config.quota_project
              @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

              @os_login_service_stub = ::Gapic::ServiceStub.new(
                ::Google::Cloud::OsLogin::V1beta::OsLoginService::Stub,
                credentials:  credentials,
                endpoint:     @config.endpoint,
                channel_args: @config.channel_args,
                interceptors: @config.interceptors
              )
            end

            # Service calls

            ##
            # Deletes a POSIX account.
            #
            # @overload delete_posix_account(request, options = nil)
            #   Pass arguments to `delete_posix_account` via a request object, either of type
            #   {::Google::Cloud::OsLogin::V1beta::DeletePosixAccountRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::OsLogin::V1beta::DeletePosixAccountRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload delete_posix_account(name: nil)
            #   Pass arguments to `delete_posix_account` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param name [::String]
            #     Required. A reference to the POSIX account to update. POSIX accounts are identified
            #     by the project ID they are associated with. A reference to the POSIX
            #     account is in format `users/{user}/projects/{project}`.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Protobuf::Empty]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Protobuf::Empty]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def delete_posix_account request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::OsLogin::V1beta::DeletePosixAccountRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.delete_posix_account.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::OsLogin::V1beta::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "name" => request.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.delete_posix_account.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.delete_posix_account.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @os_login_service_stub.call_rpc :delete_posix_account, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Deletes an SSH public key.
            #
            # @overload delete_ssh_public_key(request, options = nil)
            #   Pass arguments to `delete_ssh_public_key` via a request object, either of type
            #   {::Google::Cloud::OsLogin::V1beta::DeleteSshPublicKeyRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::OsLogin::V1beta::DeleteSshPublicKeyRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload delete_ssh_public_key(name: nil)
            #   Pass arguments to `delete_ssh_public_key` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param name [::String]
            #     Required. The fingerprint of the public key to update. Public keys are identified by
            #     their SHA-256 fingerprint. The fingerprint of the public key is in format
            #     `users/{user}/sshPublicKeys/{fingerprint}`.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Protobuf::Empty]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Protobuf::Empty]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def delete_ssh_public_key request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::OsLogin::V1beta::DeleteSshPublicKeyRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.delete_ssh_public_key.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::OsLogin::V1beta::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "name" => request.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.delete_ssh_public_key.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.delete_ssh_public_key.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @os_login_service_stub.call_rpc :delete_ssh_public_key, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Retrieves the profile information used for logging in to a virtual machine
            # on Google Compute Engine.
            #
            # @overload get_login_profile(request, options = nil)
            #   Pass arguments to `get_login_profile` via a request object, either of type
            #   {::Google::Cloud::OsLogin::V1beta::GetLoginProfileRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::OsLogin::V1beta::GetLoginProfileRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload get_login_profile(name: nil, project_id: nil, system_id: nil)
            #   Pass arguments to `get_login_profile` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param name [::String]
            #     Required. The unique ID for the user in format `users/{user}`.
            #   @param project_id [::String]
            #     The project ID of the Google Cloud Platform project.
            #   @param system_id [::String]
            #     A system ID for filtering the results of the request.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Cloud::OsLogin::V1beta::LoginProfile]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Cloud::OsLogin::V1beta::LoginProfile]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def get_login_profile request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::OsLogin::V1beta::GetLoginProfileRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.get_login_profile.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::OsLogin::V1beta::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "name" => request.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.get_login_profile.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.get_login_profile.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @os_login_service_stub.call_rpc :get_login_profile, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Retrieves an SSH public key.
            #
            # @overload get_ssh_public_key(request, options = nil)
            #   Pass arguments to `get_ssh_public_key` via a request object, either of type
            #   {::Google::Cloud::OsLogin::V1beta::GetSshPublicKeyRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::OsLogin::V1beta::GetSshPublicKeyRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload get_ssh_public_key(name: nil)
            #   Pass arguments to `get_ssh_public_key` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param name [::String]
            #     Required. The fingerprint of the public key to retrieve. Public keys are identified
            #     by their SHA-256 fingerprint. The fingerprint of the public key is in
            #     format `users/{user}/sshPublicKeys/{fingerprint}`.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Cloud::OsLogin::Common::SshPublicKey]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Cloud::OsLogin::Common::SshPublicKey]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def get_ssh_public_key request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::OsLogin::V1beta::GetSshPublicKeyRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.get_ssh_public_key.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::OsLogin::V1beta::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "name" => request.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.get_ssh_public_key.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.get_ssh_public_key.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @os_login_service_stub.call_rpc :get_ssh_public_key, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Adds an SSH public key and returns the profile information. Default POSIX
            # account information is set when no username and UID exist as part of the
            # login profile.
            #
            # @overload import_ssh_public_key(request, options = nil)
            #   Pass arguments to `import_ssh_public_key` via a request object, either of type
            #   {::Google::Cloud::OsLogin::V1beta::ImportSshPublicKeyRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::OsLogin::V1beta::ImportSshPublicKeyRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload import_ssh_public_key(parent: nil, ssh_public_key: nil, project_id: nil)
            #   Pass arguments to `import_ssh_public_key` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param parent [::String]
            #     The unique ID for the user in format `users/{user}`.
            #   @param ssh_public_key [::Google::Cloud::OsLogin::Common::SshPublicKey, ::Hash]
            #     Required. The SSH public key and expiration time.
            #   @param project_id [::String]
            #     The project ID of the Google Cloud Platform project.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Cloud::OsLogin::V1beta::ImportSshPublicKeyResponse]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Cloud::OsLogin::V1beta::ImportSshPublicKeyResponse]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def import_ssh_public_key request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::OsLogin::V1beta::ImportSshPublicKeyRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.import_ssh_public_key.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::OsLogin::V1beta::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "parent" => request.parent
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.import_ssh_public_key.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.import_ssh_public_key.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @os_login_service_stub.call_rpc :import_ssh_public_key, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Updates an SSH public key and returns the profile information. This method
            # supports patch semantics.
            #
            # @overload update_ssh_public_key(request, options = nil)
            #   Pass arguments to `update_ssh_public_key` via a request object, either of type
            #   {::Google::Cloud::OsLogin::V1beta::UpdateSshPublicKeyRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::OsLogin::V1beta::UpdateSshPublicKeyRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload update_ssh_public_key(name: nil, ssh_public_key: nil, update_mask: nil)
            #   Pass arguments to `update_ssh_public_key` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param name [::String]
            #     Required. The fingerprint of the public key to update. Public keys are identified by
            #     their SHA-256 fingerprint. The fingerprint of the public key is in format
            #     `users/{user}/sshPublicKeys/{fingerprint}`.
            #   @param ssh_public_key [::Google::Cloud::OsLogin::Common::SshPublicKey, ::Hash]
            #     Required. The SSH public key and expiration time.
            #   @param update_mask [::Google::Protobuf::FieldMask, ::Hash]
            #     Mask to control which fields get updated. Updates all if not present.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Cloud::OsLogin::Common::SshPublicKey]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Cloud::OsLogin::Common::SshPublicKey]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def update_ssh_public_key request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::OsLogin::V1beta::UpdateSshPublicKeyRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.update_ssh_public_key.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::OsLogin::V1beta::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "name" => request.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.update_ssh_public_key.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.update_ssh_public_key.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @os_login_service_stub.call_rpc :update_ssh_public_key, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Configuration class for the OsLoginService API.
            #
            # This class represents the configuration for OsLoginService,
            # providing control over timeouts, retry behavior, logging, transport
            # parameters, and other low-level controls. Certain parameters can also be
            # applied individually to specific RPCs. See
            # {::Google::Cloud::OsLogin::V1beta::OsLoginService::Client::Configuration::Rpcs}
            # for a list of RPCs that can be configured independently.
            #
            # Configuration can be applied globally to all clients, or to a single client
            # on construction.
            #
            # # Examples
            #
            # To modify the global config, setting the timeout for delete_posix_account
            # to 20 seconds, and all remaining timeouts to 10 seconds:
            #
            #     ::Google::Cloud::OsLogin::V1beta::OsLoginService::Client.configure do |config|
            #       config.timeout = 10.0
            #       config.rpcs.delete_posix_account.timeout = 20.0
            #     end
            #
            # To apply the above configuration only to a new client:
            #
            #     client = ::Google::Cloud::OsLogin::V1beta::OsLoginService::Client.new do |config|
            #       config.timeout = 10.0
            #       config.rpcs.delete_posix_account.timeout = 20.0
            #     end
            #
            # @!attribute [rw] endpoint
            #   The hostname or hostname:port of the service endpoint.
            #   Defaults to `"oslogin.googleapis.com"`.
            #   @return [::String]
            # @!attribute [rw] credentials
            #   Credentials to send with calls. You may provide any of the following types:
            #    *  (`String`) The path to a service account key file in JSON format
            #    *  (`Hash`) A service account key as a Hash
            #    *  (`Google::Auth::Credentials`) A googleauth credentials object
            #       (see the [googleauth docs](https://googleapis.dev/ruby/googleauth/latest/index.html))
            #    *  (`Signet::OAuth2::Client`) A signet oauth2 client object
            #       (see the [signet docs](https://googleapis.dev/ruby/signet/latest/Signet/OAuth2/Client.html))
            #    *  (`GRPC::Core::Channel`) a gRPC channel with included credentials
            #    *  (`GRPC::Core::ChannelCredentials`) a gRPC credentails object
            #    *  (`nil`) indicating no credentials
            #   @return [::Object]
            # @!attribute [rw] scope
            #   The OAuth scopes
            #   @return [::Array<::String>]
            # @!attribute [rw] lib_name
            #   The library name as recorded in instrumentation and logging
            #   @return [::String]
            # @!attribute [rw] lib_version
            #   The library version as recorded in instrumentation and logging
            #   @return [::String]
            # @!attribute [rw] channel_args
            #   Extra parameters passed to the gRPC channel. Note: this is ignored if a
            #   `GRPC::Core::Channel` object is provided as the credential.
            #   @return [::Hash]
            # @!attribute [rw] interceptors
            #   An array of interceptors that are run before calls are executed.
            #   @return [::Array<::GRPC::ClientInterceptor>]
            # @!attribute [rw] timeout
            #   The call timeout in seconds.
            #   @return [::Numeric]
            # @!attribute [rw] metadata
            #   Additional gRPC headers to be sent with the call.
            #   @return [::Hash{::Symbol=>::String}]
            # @!attribute [rw] retry_policy
            #   The retry policy. The value is a hash with the following keys:
            #    *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
            #    *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
            #    *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
            #    *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
            #       trigger a retry.
            #   @return [::Hash]
            # @!attribute [rw] quota_project
            #   A separate project against which to charge quota.
            #   @return [::String]
            #
            class Configuration
              extend ::Gapic::Config

              config_attr :endpoint,      "oslogin.googleapis.com", ::String
              config_attr :credentials,   nil do |value|
                allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
                allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC
                allowed.any? { |klass| klass === value }
              end
              config_attr :scope,         nil, ::String, ::Array, nil
              config_attr :lib_name,      nil, ::String, nil
              config_attr :lib_version,   nil, ::String, nil
              config_attr(:channel_args,  { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil)
              config_attr :interceptors,  nil, ::Array, nil
              config_attr :timeout,       nil, ::Numeric, nil
              config_attr :metadata,      nil, ::Hash, nil
              config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
              config_attr :quota_project, nil, ::String, nil

              # @private
              def initialize parent_config = nil
                @parent_config = parent_config unless parent_config.nil?

                yield self if block_given?
              end

              ##
              # Configurations for individual RPCs
              # @return [Rpcs]
              #
              def rpcs
                @rpcs ||= begin
                  parent_rpcs = nil
                  parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
                  Rpcs.new parent_rpcs
                end
              end

              ##
              # Configuration RPC class for the OsLoginService API.
              #
              # Includes fields providing the configuration for each RPC in this service.
              # Each configuration object is of type `Gapic::Config::Method` and includes
              # the following configuration fields:
              #
              #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
              #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers
              #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
              #     include the following keys:
              #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
              #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
              #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
              #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
              #         trigger a retry.
              #
              class Rpcs
                ##
                # RPC-specific configuration for `delete_posix_account`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :delete_posix_account
                ##
                # RPC-specific configuration for `delete_ssh_public_key`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :delete_ssh_public_key
                ##
                # RPC-specific configuration for `get_login_profile`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :get_login_profile
                ##
                # RPC-specific configuration for `get_ssh_public_key`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :get_ssh_public_key
                ##
                # RPC-specific configuration for `import_ssh_public_key`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :import_ssh_public_key
                ##
                # RPC-specific configuration for `update_ssh_public_key`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :update_ssh_public_key

                # @private
                def initialize parent_rpcs = nil
                  delete_posix_account_config = parent_rpcs.delete_posix_account if parent_rpcs.respond_to? :delete_posix_account
                  @delete_posix_account = ::Gapic::Config::Method.new delete_posix_account_config
                  delete_ssh_public_key_config = parent_rpcs.delete_ssh_public_key if parent_rpcs.respond_to? :delete_ssh_public_key
                  @delete_ssh_public_key = ::Gapic::Config::Method.new delete_ssh_public_key_config
                  get_login_profile_config = parent_rpcs.get_login_profile if parent_rpcs.respond_to? :get_login_profile
                  @get_login_profile = ::Gapic::Config::Method.new get_login_profile_config
                  get_ssh_public_key_config = parent_rpcs.get_ssh_public_key if parent_rpcs.respond_to? :get_ssh_public_key
                  @get_ssh_public_key = ::Gapic::Config::Method.new get_ssh_public_key_config
                  import_ssh_public_key_config = parent_rpcs.import_ssh_public_key if parent_rpcs.respond_to? :import_ssh_public_key
                  @import_ssh_public_key = ::Gapic::Config::Method.new import_ssh_public_key_config
                  update_ssh_public_key_config = parent_rpcs.update_ssh_public_key if parent_rpcs.respond_to? :update_ssh_public_key
                  @update_ssh_public_key = ::Gapic::Config::Method.new update_ssh_public_key_config

                  yield self if block_given?
                end
              end
            end
          end
        end
      end
    end
  end
end
